#[non_exhaustive]pub enum PresenceSharingHint {
Forbid,
Suggest,
}Expand description
A room’s presence sharing hint.
The room’s presence sharing hint indicates either:
- Sharing presence within the room is prohibited (Self::Forbid), or
- Sharing presence within the room should be recommended by clients (Self::Suggest)
This type is defined in MSC4495.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Forbid
Sharing presence within the room is prohibited.
Suggest
Sharing presence within the room should be recommended by clients.
Implementations