#[non_exhaustive]pub struct RoomPresenceSharingEventContent {
pub presence_sharing: PresenceSharingHint,
}Expand description
The content of an m.room.presence_sharing event.
The room’s presence sharing hint indicates either:
- Sharing presence within the room is prohibited (
forbid), or - Sharing presence within the room should be recommended by clients (
suggest)
This event uses the unstable prefix defined in MSC4495.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.presence_sharing: PresenceSharingHintThe room’s presence sharing hint.
Implementations
Sourceimpl RoomPresenceSharingEventContent
impl RoomPresenceSharingEventContent
Sourcepub fn new(hint: PresenceSharingHint) -> Self
pub fn new(hint: PresenceSharingHint) -> Self
Creates a new RoomPresenceSharingEventContent with the given hint.