pub type InitialRoomPresenceSharingEvent = InitialStateEvent<RoomPresenceSharingEventContent>;Expand description
An org.continuwuity.presence_v2.msc4495.room.presence_sharing event for creating a room.
Aliased Type
pub struct InitialRoomPresenceSharingEvent {
pub content: RoomPresenceSharingEventContent,
pub state_key: EmptyStateKey,
}Fields
content: RoomPresenceSharingEventContentData specific to the event type.
state_key: EmptyStateKeyA unique key which defines the overwriting semantics for this piece of room state.
This must be a string type, and is often an empty string.
A state event is keyed by its (type, state_key) tuple. Sending another state event with
the same tuple replaces the previous one.
Defaults to the empty string.