pub type StrippedRoomPresenceSharingEvent = StrippedStateEvent<PossiblyRedactedRoomPresenceSharingEventContent>;Expand description
An org.continuwuity.presence_v2.msc4495.room.presence_sharing event from an invited room preview.
Aliased Type
pub struct StrippedRoomPresenceSharingEvent {
pub content: PossiblyRedactedRoomPresenceSharingEventContent,
pub sender: OwnedUserId,
pub state_key: EmptyStateKey,
pub origin_server_ts: Option<MilliSecondsSinceUnixEpoch>,
pub unsigned: Option<Raw<StateUnsigned<PossiblyRedactedRoomPresenceSharingEventContent>>>,
}Fields
content: PossiblyRedactedRoomPresenceSharingEventContentData specific to the event type.
sender: OwnedUserIdThe fully-qualified ID of the user who sent this event.
state_key: EmptyStateKeyA unique key which defines the overwriting semantics for this piece of room state.
This must be a string type, and is often an empty string.
A state event is keyed by its (type, state_key) tuple. Sending another state event with
the same tuple replaces the previous one.
origin_server_ts: Option<MilliSecondsSinceUnixEpoch>Timestamp on the originating homeserver when this event was sent.
This field is usually stripped, but some events might include it.
unsigned: Option<Raw<StateUnsigned<PossiblyRedactedRoomPresenceSharingEventContent>>>Additional key-value pairs not signed by the homeserver.